summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/objecttreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/objecttreeview.h')
-rw-r--r--kexi/formeditor/objecttreeview.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/kexi/formeditor/objecttreeview.h b/kexi/formeditor/objecttreeview.h
index 393f3ba08..46266144b 100644
--- a/kexi/formeditor/objecttreeview.h
+++ b/kexi/formeditor/objecttreeview.h
@@ -31,12 +31,12 @@ class Form;
class KFORMEDITOR_EXPORT ObjectTreeViewItem : public KListViewItem
{
public:
- ObjectTreeViewItem(ObjectTreeViewItem *parent, ObjectTreeItem *item);
+ ObjectTreeViewItem(ObjectTreeViewItem *tqparent, ObjectTreeItem *item);
ObjectTreeViewItem(KListView *list, ObjectTreeItem *item=0);
virtual ~ObjectTreeViewItem();
//! \return the item name, ie the ObjectTreeItem name
- QString name() const;
+ TQString name() const;
//! \return the ObjectTreeItem associated to this item.
ObjectTreeItem* objectTree() const { return m_item; }
@@ -45,10 +45,10 @@ class KFORMEDITOR_EXPORT ObjectTreeViewItem : public KListViewItem
protected:
//! Reimplemented to draw custom contents (copied from Property Editor)
- virtual void paintCell(QPainter *p, const QColorGroup & cg, int column, int width, int align);
+ virtual void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
//! Reimplemented to draw custom contents (copied from Property Editor)
- virtual void paintBranches(QPainter *p, const QColorGroup &cg, int w, int y, int h);
+ virtual void paintBranches(TQPainter *p, const TQColorGroup &cg, int w, int y, int h);
//! Reimplemented to draw custom contents (copied from Property Editor)
virtual void setup();
@@ -67,12 +67,13 @@ class KFORMEDITOR_EXPORT ObjectTreeViewItem : public KListViewItem
class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
- ObjectTreeView(QWidget *parent=0, const char *name=0, bool tabStop = false);
+ ObjectTreeView(TQWidget *tqparent=0, const char *name=0, bool tabStop = false);
virtual ~ObjectTreeView();
- virtual QSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/*! Sets \a form as the current Form in the list. The list will automatically
be filled with an item for each widget in the Form, and selection will be synced.
@@ -81,26 +82,26 @@ class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
void setForm(Form *form);
//! \return the pixmap name for a given class, to be shown next to the widget name.
- QString iconNameForClass(const QCString &classname);
+ TQString iconNameForClass(const TQCString &classname);
public slots:
/*! Sets the widget \a w as selected item, so it will be written bold.
It is added to current selection if \a add is true. */
- void setSelectedWidget(QWidget *w, bool add=false);
+ void setSelectedWidget(TQWidget *w, bool add=false);
- /*! Adds the ObjectTreeItem \a item in the list, with the appropriate parent. */
+ /*! Adds the ObjectTreeItem \a item in the list, with the appropriate tqparent. */
void addItem(ObjectTreeItem *item);
/*! Removess the ObjectTreeItem \a item from the list. */
void removeItem(ObjectTreeItem *item);
/*! Just renames the list item from \a oldname to \a newname. */
- void renameItem(const QCString &oldname, const QCString &newname);
+ void renameItem(const TQCString &oldname, const TQCString &newname);
protected slots:
/*! This slot is called when the user right-click a list item.
The widget context menu is shown, as inisde the Form. */
- void displayContextMenu(KListView *list, QListViewItem *item, const QPoint &p);
+ void displayContextMenu(KListView *list, TQListViewItem *item, const TQPoint &p);
void slotColumnSizeChanged(int);
@@ -112,10 +113,10 @@ class KFORMEDITOR_EXPORT ObjectTreeView : public KListView
protected:
//! Internal function to fill the list.
- ObjectTreeViewItem* loadTree(ObjectTreeItem *item, ObjectTreeViewItem *parent);
+ ObjectTreeViewItem* loadTree(ObjectTreeItem *item, ObjectTreeViewItem *tqparent);
//! \return The item whose name is \a name.
- ObjectTreeViewItem* findItem(const QString &name);
+ ObjectTreeViewItem* findItem(const TQString &name);
private:
Form *m_form;